Struct polkadot_service::generic::Header [−][src]
pub struct Header<Number, Hash> where
Number: Copy + Into<U256> + TryFrom<U256>,
Hash: Hash, {
pub parent_hash: <Hash as Hash>::Output,
pub number: Number,
pub state_root: <Hash as Hash>::Output,
pub extrinsics_root: <Hash as Hash>::Output,
pub digest: Digest,
}Expand description
Abstraction over a block header for a substrate chain.
Fields
parent_hash: <Hash as Hash>::OutputThe parent hash.
number: NumberThe block number.
state_root: <Hash as Hash>::OutputThe state trie merkle root
extrinsics_root: <Hash as Hash>::OutputThe merkle root of the extrinsics.
digest: DigestA chain-specific digest of data useful for light clients or referencing auxiliary data.
Implementations
impl<Number, Hash> Header<Number, Hash> where
Number: Member + Hash + Copy + MaybeDisplay + AtLeast32BitUnsigned + Codec + Into<U256> + TryFrom<U256>,
Hash: Hash,
<Hash as Hash>::Output: Default,
<Hash as Hash>::Output: Hash,
<Hash as Hash>::Output: Copy,
<Hash as Hash>::Output: Member,
<Hash as Hash>::Output: MaybeDisplay,
<Hash as Hash>::Output: SimpleBitOps,
<Hash as Hash>::Output: Codec,
impl<Number, Hash> Header<Number, Hash> where
Number: Member + Hash + Copy + MaybeDisplay + AtLeast32BitUnsigned + Codec + Into<U256> + TryFrom<U256>,
Hash: Hash,
<Hash as Hash>::Output: Default,
<Hash as Hash>::Output: Hash,
<Hash as Hash>::Output: Copy,
<Hash as Hash>::Output: Member,
<Hash as Hash>::Output: MaybeDisplay,
<Hash as Hash>::Output: SimpleBitOps,
<Hash as Hash>::Output: Codec,
pub fn new_from_number(
number: <Header<u64, BlakeTwo256> as Header>::Number
) -> Header<u64, BlakeTwo256>
pub fn new_from_number(
number: <Header<u64, BlakeTwo256> as Header>::Number
) -> Header<u64, BlakeTwo256>
A new header with the given number and default hash for all other fields.