Struct polkadot_service::generic::UncheckedExtrinsic [−][src]
pub struct UncheckedExtrinsic<Address, Call, Signature, Extra> where
Extra: SignedExtension, {
pub signature: Option<(Address, Signature, Extra)>,
pub function: Call,
}Expand description
A extrinsic right from the external world. This is unchecked and so can contain a signature.
Fields
signature: Option<(Address, Signature, Extra)>The signature, address, number of extrinsics have come before from the same signer and an era describing the longevity of this transaction, if this is a signed extrinsic.
function: CallThe function that should be called.
Implementations
impl<Address, Call, Signature, Extra> UncheckedExtrinsic<Address, Call, Signature, Extra> where
Extra: SignedExtension,
impl<Address, Call, Signature, Extra> UncheckedExtrinsic<Address, Call, Signature, Extra> where
Extra: SignedExtension,
pub fn new_signed(
function: Call,
signed: Address,
signature: Signature,
extra: Extra
) -> UncheckedExtrinsic<Address, Call, Signature, Extra>
pub fn new_signed(
function: Call,
signed: Address,
signature: Signature,
extra: Extra
) -> UncheckedExtrinsic<Address, Call, Signature, Extra>
New instance of a signed extrinsic aka “transaction”.
New instance of an unsigned extrinsic aka “inherent”.